@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -82,7 +82,7 @@ public enum SubscriptionJSONErrorMessages implements OXErrorMessage {
 
     private int errorCode;
     
-    public static SubscriptionJSONExceptions FACTORY = new SubscriptionJSONExceptions();
+    public static final SubscriptionJSONExceptions FACTORY = new SubscriptionJSONExceptions();
     
     /**
      * Initializes a new {@link SubscriptionJSONErrorMessages}.
